@@ -1,6 +1,5 @@
-import { fireEvent, render, screen, waitFor } from '@testing-library/react';
+import { render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
-import React from 'react';
 import { TestProvider } from 'test/helpers/TestProvider';
 import { selectOptionInTest } from 'test/helpers/selectOptionInTest';
 
@@ -13,7 +12,10 @@ import reportsReducers, { initialState, updateReportProp } from '../state/reduce
 
 import { Schedule, Props } from './Schedule';
 
+let user: ReturnType<typeof userEvent.setup>;
+
 beforeEach(() => {
+  user = userEvent.setup();
   jest.clearAllMocks();
 });
 
@@ -27,6 +29,7 @@ jest.mock('app/core/services/backend_srv', () => {
 
 jest.mock('@grafana/runtime/src/config', () => ({
   config: {
+    ...jest.requireActual('@grafana/runtime/src/config').config,
     buildInfo: {
       edition: 'Enterprise',
       version: '9.0.0',
@@ -105,7 +108,7 @@ describe('Report Scheduling', () => {
     expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
 
     // Select "Send later"
-    fireEvent.click(screen.getByRole('radio', { name: /later/ }));
+    await user.click(screen.getByRole('radio', { name: /later/ }));
     expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
     expect(screen.getByText(/start time/i)).toBeVisible();
     expect(screen.getByText(/time zone/i)).toBeVisible();
@@ -118,41 +121,41 @@ describe('Report Scheduling', () => {
       setup();
     });
 
-    const selectDate = (date: string, type = 'start') => {
+    const selectDate = async (date: string, type = 'start') => {
       const re = type === 'start' ? /report schedule start date/i : /report schedule end date/i;
-      fireEvent.click(screen.getByLabelText(re));
-      fireEvent.click(screen.getByRole('button', { name: date }));
+      await user.click(screen.getByLabelText(re));
+      await user.click(screen.getByRole('button', { name: date }));
     };
 
-    it('once', () => {
-      fireEvent.click(screen.getByRole('radio', { name: /once/i }));
+    it('once', async () => {
+      await user.click(screen.getByRole('radio', { name: /once/i }));
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
       expect(screen.getByText('The report will be sent immediately after it is saved.')).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
+      await user.click(screen.getByRole('radio', { name: /later/i }));
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.getByText(/The report will be sent: Once on January 1, 2020/i)).toBeInTheDocument();
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
     });
 
-    it('hourly', () => {
-      fireEvent.click(screen.getByRole('radio', { name: /hourly/i }));
+    it('hourly', async () => {
+      await user.click(screen.getByRole('radio', { name: /hourly/i }));
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
       expect(
         screen.getByText('The report will be sent immediately after it is saved and will be sent every hour.')
       ).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
-      selectDate('January 1, 2020');
+      await user.click(screen.getByRole('radio', { name: /later/i }));
+      await selectDate('January 1, 2020');
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
       expect(screen.getByText(/The report will be sent: Hourly at minute 00/i)).toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('');
-      fireEvent.click(screen.getByLabelText(/report schedule end date/i));
-      fireEvent.click(screen.getByRole('button', { name: 'January 11, 2020' }));
+      await user.click(screen.getByLabelText(/report schedule end date/i));
+      await user.click(screen.getByRole('button', { name: 'January 11, 2020' }));
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('01/11/2020');
       expect(screen.getByText(/end time/i)).toBeInTheDocument();
       expect(
@@ -160,16 +163,16 @@ describe('Report Scheduling', () => {
       ).toBeInTheDocument();
     });
 
-    it('daily', () => {
-      fireEvent.click(screen.getByRole('radio', { name: /daily/i }));
+    it('daily', async () => {
+      await user.click(screen.getByRole('radio', { name: /daily/i }));
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
+      await user.click(screen.getByRole('radio', { name: /later/i }));
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
-      selectDate('January 1, 2020');
-      selectDate('January 11, 2020', 'end');
+      await selectDate('January 1, 2020');
+      await selectDate('January 11, 2020', 'end');
       expect(screen.getByText(/January 1, 2020 - January 11, 2020/i));
-      fireEvent.click(screen.getByRole('radio', { name: /send now/i }));
+      await user.click(screen.getByRole('radio', { name: /send now/i }));
       // start date and time fields are hidden, not removed from DOM
       expect(screen.queryByLabelText(/report schedule start date/i)).not.toBeVisible();
       expect(screen.queryByText(/start time/i)).not.toBeVisible();
@@ -179,8 +182,8 @@ describe('Report Scheduling', () => {
         screen.getByText(/The report will be sent immediately after it is saved and will be sent every day./i)
       ).toBeInTheDocument();
     });
-    it('weekly', () => {
-      fireEvent.click(screen.getByRole('radio', { name: /weekly/i }));
+    it('weekly', async () => {
+      await user.click(screen.getByRole('radio', { name: /weekly/i }));
       expect(screen.queryByLabelText(/report schedule start date/i)).not.toBeVisible();
       expect(screen.queryByText(/start time/i)).not.toBeVisible();
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
@@ -188,21 +191,21 @@ describe('Report Scheduling', () => {
       expect(
         screen.getByText(/The report will be sent immediately after it is saved and will be sent every week./i)
       ).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
-      selectDate('January 1, 2020');
-      selectDate('January 11, 2020', 'end');
+      await user.click(screen.getByRole('radio', { name: /later/i }));
+      await selectDate('January 1, 2020');
+      await selectDate('January 11, 2020', 'end');
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByText(/The report will be sent: Every Wednesday at 00:00/i));
     });
     it('monthly', async () => {
-      fireEvent.click(screen.getByRole('radio', { name: /monthly/i }));
+      await user.click(screen.getByRole('radio', { name: /monthly/i }));
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
+      await user.click(screen.getByRole('radio', { name: /later/i }));
       expect(screen.getByRole('checkbox', { name: /send on the last day of month/i })).toBeInTheDocument();
-      selectDate('January 1, 2020');
-      selectDate('January 11, 2020', 'end');
+      await selectDate('January 1, 2020');
+      await selectDate('January 11, 2020', 'end');
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.getByLabelText(/report schedule end date/i)).toBeVisible();
@@ -212,11 +215,11 @@ describe('Report Scheduling', () => {
           /The report will be sent: Monthly on the 1st day at 00:00 UTC-05:00, January 1, 2020 - January 11, 2020./i
         )
       ).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('checkbox', { name: /send on the last day of month/i }));
+      await user.click(screen.getByRole('checkbox', { name: /send on the last day of month/i }));
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/31/2020');
-      await userEvent.clear(screen.getByLabelText(/report schedule end date/i));
+      await user.clear(screen.getByLabelText(/report schedule end date/i));
       expect(screen.getByText(/The report will be sent: Monthly on the last day at 00:00./i)).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('radio', { name: /send now/i }));
+      await user.click(screen.getByRole('radio', { name: /send now/i }));
       expect(screen.queryByRole('checkbox', { name: /send on the last day of month/i })).not.toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule start date/i)).not.toBeVisible();
       expect(screen.getByText(/start time/i)).not.toBeVisible();
@@ -228,7 +231,7 @@ describe('Report Scheduling', () => {
     });
 
     it('custom', async () => {
-      fireEvent.click(screen.getByRole('radio', { name: /custom/i }));
+      await user.click(screen.getByRole('radio', { name: /custom/i }));
       expect(screen.getByRole('radio', { name: /send now/i })).toBeChecked();
       expect(screen.getByLabelText(/repeat every/i)).toBeInTheDocument();
       expect(screen.getByLabelText(/custom frequency/i)).toBeInTheDocument();
@@ -236,12 +239,12 @@ describe('Report Scheduling', () => {
       expect(
         screen.getByText(/The report will be sent immediately after it is saved and will be sent every 2 hours./i)
       ).toBeInTheDocument();
-      fireEvent.click(screen.getByRole('radio', { name: /later/i }));
+      await user.click(screen.getByRole('radio', { name: /later/i }));
       expect(screen.getByText(/The report will be sent: Every 2 hours./i)).toBeInTheDocument();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toBeVisible();
-      selectDate('January 1, 2020');
-      selectDate('January 11, 2020', 'end');
+      await selectDate('January 1, 2020');
+      await selectDate('January 11, 2020', 'end');
       expect(screen.getByText(/end time/i)).toBeInTheDocument();
       await selectOptionInTest(screen.getByLabelText(/custom frequency/i), 'months');
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
@@ -250,8 +253,8 @@ describe('Report Scheduling', () => {
       ).toBeInTheDocument();
     });
 
-    it('never', () => {
-      fireEvent.click(screen.getByRole('radio', { name: /never/i }));
+    it('never', async () => {
+      await user.click(screen.getByRole('radio', { name: /never/i }));
       expect(screen.queryByRole('radio', { name: /send now/i })).not.toBeInTheDocument();
       expect(screen.queryByLabelText(/report schedule start date/i)).not.toBeVisible();
       expect(screen.queryByText(/start time/i)).not.toBeVisible();
@@ -432,19 +435,19 @@ describe('Report Scheduling', () => {
       updateReportProp: mockUpdate,
     });
     expect(await screen.findByText(/3. Schedule/i)).toBeInTheDocument();
-    fireEvent.click(screen.getByRole('radio', { name: 'Monthly' }));
+    await user.click(screen.getByRole('radio', { name: 'Monthly' }));
 
-    fireEvent.click(screen.getByLabelText(/report schedule start date/i));
-    fireEvent.click(screen.getByRole('button', { name: 'January 11, 2021' }));
+    await user.click(screen.getByLabelText(/report schedule start date/i));
+    await user.click(screen.getByRole('button', { name: 'January 11, 2021' }));
     expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/11/2021');
 
     await selectOptionInTest(screen.getByDisplayValue('00:00'), '04');
 
     // Close the time picker overlay by clicking away
-    await userEvent.click(screen.getByRole('radio', { name: 'Monthly' }));
+    await user.click(screen.getByRole('radio', { name: 'Monthly' }));
 
     await selectOptionInTest(screen.getByLabelText('Time zone picker'), 'Europe/Rome');
-    fireEvent.submit(screen.getByRole('button', { name: /next/i }));
+    await user.click(screen.getByRole('button', { name: /next/i }));
 
     await waitFor(() =>
       expect(mockUpdate).toHaveBeenCalledWith({
@@ -469,15 +472,15 @@ describe('Report Scheduling', () => {
       updateReportProp: mockUpdate,
     });
     expect(await screen.findByText(/3. Schedule/i)).toBeInTheDocument();
-    fireEvent.click(screen.getByRole('radio', { name: 'Custom' }));
-    await userEvent.clear(screen.getByLabelText(/repeat every/i));
-    await userEvent.type(screen.getByLabelText(/repeat every/i), '5');
+    await user.click(screen.getByRole('radio', { name: 'Custom' }));
+    await user.clear(screen.getByLabelText(/repeat every/i));
+    await user.type(screen.getByLabelText(/repeat every/i), '5');
 
-    fireEvent.click(screen.getByRole('checkbox', { name: /send monday to friday/i }));
+    await user.click(screen.getByRole('checkbox', { name: /send monday to friday/i }));
 
     await selectOptionInTest(screen.getByLabelText('Time zone picker'), 'Europe/Helsinki');
 
-    fireEvent.submit(screen.getByRole('button', { name: /next/i }));
+    await user.click(screen.getByRole('button', { name: /next/i }));
 
     await waitFor(() =>
       expect(mockUpdate).toHaveBeenCalledWith({
